"use strict";
const tslib_1 = require("tslib");
const confusing_browser_globals_1 = tslib_1.__importDefault(require("confusing-browser-globals"));
const utils_1 = require("./utils");
module.exports = {
    env: { es6: true },
    parserOptions: {
        ecmaVersion: 2020,
        ecmaFeatures: {
            impliedStrict: true,
        },
        sourceType: 'module',
    },
    settings: {
        'jsdoc': {
            mode: 'closure',
        },
        'import/cache': {
            lifetime: '60',
        },
        'import/extensions': ['.ts', '.tsx', '.js', '.jsx'],
        'import/ignore': ['\\.(scss|less|css)$', '\\.(png|jpg|svg)$'],
        'import/parsers': {
            '@typescript-eslint/parser': ['.ts', '.tsx'],
        },
    },
    plugins: [
        'eslint-comments',
        'fp',
        'import',
        'jsdoc',
        'no-secrets',
        'prefer-arrow',
        'sonarjs',
        'security',
        'sort-destructure-keys',
        'ternary',
        'unicorn',
    ],
    rules: {
        // plugin:eslint ***********************************************************
        // rules URL: https://github.com/eslint/eslint/tree/master/docs/rules
        // Possible Errors
        'for-direction': utils_1.WARN,
        'getter-return': utils_1.WARN,
        'no-async-promise-executor': utils_1.WARN,
        'no-await-in-loop': (0, utils_1.OFF)('While in many cases you do want to avoid await in loops, there are cases where order matters in which this does not apply.'),
        'no-compare-neg-zero': utils_1.WARN,
        'no-cond-assign': utils_1.WARN,
        'no-console': [utils_1.WARN, { allow: ['warn', 'error'] }],
        'no-constant-condition': utils_1.WARN,
        'no-control-regex': utils_1.WARN,
        'no-debugger': utils_1.WARN,
        'no-dupe-args': utils_1.WARN,
        'no-dupe-keys': utils_1.WARN,
        'no-duplicate-case': utils_1.WARN,
        'no-empty': [utils_1.WARN, { allowEmptyCatch: true }],
        'no-empty-character-class': utils_1.WARN,
        'no-ex-assign': utils_1.WARN,
        'no-extra-boolean-cast': utils_1.WARN,
        'no-func-assign': utils_1.WARN,
        'no-import-assign': utils_1.WARN,
        'no-inner-declarations': (0, utils_1.BUGGY)('unknown', "doesn't play nice with namespaces https://github.com/typescript-eslint/typescript-eslint/issues/239"),
        'no-invalid-regexp': utils_1.WARN,
        'no-irregular-whitespace': utils_1.WARN,
        'no-loss-of-precision': utils_1.WARN,
        'no-misleading-character-class': utils_1.WARN,
        'no-obj-calls': utils_1.WARN,
        'no-promise-executor-return': utils_1.WARN,
        'no-prototype-builtins': utils_1.WARN,
        'no-regex-spaces': utils_1.WARN,
        'no-setter-return': utils_1.WARN,
        'no-sparse-arrays': utils_1.WARN,
        'no-template-curly-in-string': utils_1.WARN,
        'no-unreachable': utils_1.WARN,
        'no-unreachable-loop': utils_1.WARN,
        'no-unsafe-finally': utils_1.WARN,
        'no-unsafe-negation': utils_1.WARN,
        'no-unsafe-optional-chaining': utils_1.WARN,
        'no-useless-backreference': utils_1.WARN,
        'require-atomic-updates': utils_1.WARN,
        'use-isnan': utils_1.WARN,
        'valid-typeof': utils_1.WARN,
        // Best Practices
        'accessor-pairs': utils_1.WARN,
        'array-callback-return': [utils_1.WARN, { allowImplicit: true }],
        'block-scoped-var': utils_1.WARN,
        'class-methods-use-this': (0, utils_1.OFF)('Some frameworks (angular) require methods for templates to reference'),
        'complexity': [utils_1.WARN, { max: 50 }],
        'consistent-return': utils_1.WARN,
        'curly': [utils_1.WARN, 'all'],
        'default-case': [utils_1.WARN, { commentPattern: '^no default$' }],
        'default-case-last': utils_1.WARN,
        'default-param-last': utils_1.WARN,
        'dot-notation': utils_1.WARN,
        'eqeqeq': [utils_1.WARN, 'always'],
        'grouped-accessor-pairs': utils_1.WARN,
        'guard-for-in': utils_1.WARN,
        'max-classes-per-file': [utils_1.WARN, 1],
        'no-alert': utils_1.WARN,
        'no-caller': utils_1.WARN,
        'no-case-declarations': utils_1.WARN,
        'no-constructor-return': utils_1.ERROR,
        'no-constant-binary-expression': utils_1.WARN,
        'no-div-regex': utils_1.WARN,
        'no-duplicate-imports': utils_1.WARN,
        'no-else-return': utils_1.WARN,
        'no-empty-function': [
            utils_1.WARN,
            {
                allow: ['arrowFunctions', 'functions', 'methods'],
            },
        ],
        'no-empty-pattern': utils_1.WARN,
        'no-eq-null': utils_1.WARN,
        'no-eval': utils_1.WARN,
        'no-extend-native': utils_1.WARN,
        'no-extra-bind': utils_1.WARN,
        'no-extra-label': utils_1.WARN,
        'no-fallthrough': (0, utils_1.SUCCESSOR)('tsc:noFallthroughCasesInSwitch'),
        'no-global-assign': [utils_1.ERROR, { exceptions: [] }],
        'no-implicit-coercion': utils_1.WARN,
        'no-implicit-globals': utils_1.WARN,
        'no-implied-eval': utils_1.ERROR,
        'no-invalid-this': utils_1.WARN,
        'no-iterator': utils_1.WARN,
        'no-labels': [utils_1.WARN, { allowLoop: false, allowSwitch: false }],
        'no-lone-blocks': utils_1.WARN,
        'no-loop-func': utils_1.WARN,
        'no-magic-numbers': (0, utils_1.BUGGY)('unknown', 'sounds good in theory, but works poorly in practice'),
        'no-multi-str': utils_1.WARN,
        'no-new': utils_1.WARN,
        'no-new-func': utils_1.WARN,
        'no-new-wrappers': utils_1.WARN,
        'no-nonoctal-decimal-escape': utils_1.WARN,
        'no-octal': utils_1.WARN,
        'no-octal-escape': utils_1.WARN,
        'no-param-reassign': utils_1.WARN,
        'no-proto': utils_1.WARN,
        'no-redeclare': utils_1.WARN,
        'no-restricted-properties': [
            utils_1.WARN,
            {
                object: 'arguments',
                property: 'callee',
                message: 'arguments.callee is deprecated',
            },
            {
                object: 'global',
                property: 'isFinite',
                message: 'Please use Number.isFinite instead',
            },
            {
                object: 'self',
                property: 'isFinite',
                message: 'Please use Number.isFinite instead',
            },
            {
                object: 'window',
                property: 'isFinite',
                message: 'Please use Number.isFinite instead',
            },
            {
                object: 'global',
                property: 'isNaN',
                message: 'Please use Number.isNaN instead',
            },
            {
                object: 'self',
                property: 'isNaN',
                message: 'Please use Number.isNaN instead',
            },
            {
                object: 'window',
                property: 'isNaN',
                message: 'Please use Number.isNaN instead',
            },
            {
                property: '__defineGetter__',
                message: 'Please use Object.defineProperty instead.',
            },
            {
                property: '__defineSetter__',
                message: 'Please use Object.defineProperty instead.',
            },
            {
                object: 'Math',
                property: 'pow',
                message: 'Use the exponentiation operator (**) instead.',
            },
        ],
        'no-return-assign': utils_1.WARN,
        'no-return-await': utils_1.WARN,
        'no-script-url': utils_1.WARN,
        'no-self-assign': utils_1.WARN,
        'no-self-compare': utils_1.WARN,
        'no-sequences': utils_1.WARN,
        'no-throw-literal': utils_1.WARN,
        'no-unmodified-loop-condition': utils_1.WARN,
        'no-unused-expressions': utils_1.WARN,
        'no-unused-labels': utils_1.WARN,
        'no-unused-private-class-members': utils_1.WARN,
        'no-useless-call': utils_1.WARN,
        'no-useless-catch': utils_1.WARN,
        'no-useless-concat': utils_1.WARN,
        'no-useless-escape': utils_1.WARN,
        'no-useless-return': utils_1.WARN,
        'no-void': (0, utils_1.OFF)('The void operator has meaningful uses such as showing the intent to eat the result of a promise'),
        'no-warning-comments': (0, utils_1.SUCCESSOR)('unicorn/expiring-todo-comments'),
        'no-with': utils_1.WARN,
        'prefer-named-capture-group': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'prefer-object-has-own': (0, utils_1.SUCCESSOR)('unicorn/prefer-object-has-own'),
        'prefer-promise-reject-errors': utils_1.WARN,
        'prefer-regex-literals': utils_1.WARN,
        'radix': utils_1.WARN,
        'require-await': utils_1.WARN,
        'require-unicode-regexp': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'vars-on-top': utils_1.WARN,
        'yoda': (0, utils_1.OFF)('not needed because `no-cond-assign` covers this error'),
        // Strict Mode
        'strict': [utils_1.WARN, 'safe'],
        // Variables
        'init-declarations': (0, utils_1.OFF)("I don't have a super strong feeling on this one since the presence of TypeScript kinda forces you to init declarations anyway"),
        'no-delete-var': utils_1.WARN,
        'no-label-var': utils_1.WARN,
        'no-restricted-globals': [utils_1.WARN, ...confusing_browser_globals_1.default],
        'no-shadow': utils_1.WARN,
        'no-shadow-restricted-names': utils_1.WARN,
        'no-undef': utils_1.ERROR,
        'no-undef-init': utils_1.WARN,
        'no-undefined': (0, utils_1.OFF)("I look forward to a world where the problem that necessitates this rule's existence doesn't exist anymore.  Although shadowing `undefined` is super nasty, the utility of this language primitive is too strong to disable outright."),
        'no-unused-vars': [utils_1.WARN, { ignoreRestSiblings: true, argsIgnorePattern: '^_' }],
        'no-use-before-define': utils_1.WARN,
        // Stylistic Issues
        'camelcase': utils_1.WARN,
        'capitalized-comments': (0, utils_1.OFF)('the reality is that to many things exist in comments that should not be bound by rules (compiler directives, jsDoc, type information, etc.)'),
        'consistent-this': [utils_1.WARN, 'self'],
        'func-name-matching': utils_1.WARN,
        'func-names': utils_1.UNKNOWN,
        'func-style': [utils_1.WARN, 'declaration', { allowArrowFunctions: true }],
        'id-denylist': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'id-length': [
            utils_1.WARN,
            {
                min: 2,
                exceptions: [
                    'a',
                    'b',
                    'x',
                    'y',
                    '_',
                    'i',
                    'j', // iterators
                ],
                properties: 'never', // sometimes there are properties in existing data (i.e. 3rd party data) you are trying to map to that you simply can't control.
            },
        ],
        'id-match': (0, utils_1.SUCCESSOR)('@typescript-eslint/naming-convention'),
        'lines-between-class-members': [utils_1.WARN, 'always', { exceptAfterSingleLine: true }],
        'max-depth': [utils_1.WARN, 5],
        'max-lines': [utils_1.WARN, { max: 1000 }],
        'max-lines-per-function': [
            utils_1.WARN,
            {
                max: 150,
                skipBlankLines: true,
                skipComments: true,
                IIFEs: false,
            },
        ],
        'max-nested-callbacks': utils_1.WARN,
        'max-params': [utils_1.WARN, { max: 6 }],
        'max-statements': [utils_1.WARN, { max: 30 }],
        'max-statements-per-line': [utils_1.WARN, { max: 2 }],
        'multiline-comment-style': (0, utils_1.OFF)('The programmer should be free to comment code how they like (that is to say, almost never).'),
        'new-cap': (0, utils_1.OFF)('`new` should, these days, basically not be used'),
        'no-array-constructor': utils_1.WARN,
        'no-bitwise': utils_1.WARN,
        'no-continue': (0, utils_1.OFF)("Shouldn't be using labels. This encourages labels."),
        'no-inline-comments': (0, utils_1.OFF)('inline comments === good.'),
        'no-lonely-if': utils_1.WARN,
        'no-mixed-operators': [
            utils_1.WARN,
            {
                groups: [
                    ['&', '|', '^', '~', '<<', '>>', '>>>'],
                    ['==', '!=', '===', '!==', '>', '>=', '<', '<='],
                    ['&&', '||'],
                    ['in', 'instanceof'],
                ],
                allowSamePrecedence: false,
            },
        ],
        'no-multi-assign': utils_1.WARN,
        'no-negated-condition': (0, utils_1.OFF)('when checking for falsy conditions in ternaries negative conditions feel more natural'),
        'no-nested-ternary': (0, utils_1.SUCCESSOR)('ternary/nesting'),
        'no-new-object': utils_1.WARN,
        'no-plusplus': utils_1.WARN,
        'no-restricted-syntax': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'no-ternary': (0, utils_1.OFF)("ternaries are more complex, yes, but it's a level of complexity I think is more than acceptable in the context of the kinds of functional programming use cases this config is intended for."),
        'no-underscore-dangle': (0, utils_1.OFF)("it has a legitimate semantic meaning that's widely used."),
        'no-unneeded-ternary': utils_1.WARN,
        'one-var': [utils_1.WARN, 'never'],
        'operator-assignment': utils_1.WARN,
        'prefer-exponentiation-operator': utils_1.WARN,
        'prefer-object-spread': utils_1.WARN,
        'sort-keys': (0, utils_1.OFF)('There are too many use cases where the order of keys should not be alphabetical'),
        'sort-vars': utils_1.WARN,
        'spaced-comment': [
            utils_1.WARN,
            'always',
            {
                exceptions: ['/', '*', '-', '* '],
                markers: [
                    '/',
                    '?', // for Quokka
                ],
            },
        ],
        // Disabled due to overlap with code formatters, eg Prettier
        'lines-around-comment': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'max-len': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-confusing-arrow': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-tabs': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-unexpected-multiline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'quotes': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'array-bracket-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'array-bracket-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'array-element-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'arrow-parens': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'arrow-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'block-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'brace-style': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'comma-dangle': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'comma-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'comma-style': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'computed-property-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'dot-location': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'eol-last': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'func-call-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'function-call-argument-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'function-paren-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'generator-star': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'generator-star-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'implicit-arrow-linebreak': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'indent': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'jsx-quotes': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'key-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'keyword-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'line-comment-position': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'linebreak-style': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'multiline-ternary': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'newline-per-chained-call': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'new-parens': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-arrow-condition': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-comma-dangle': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-extra-parens': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-extra-semi': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-floating-decimal': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-mixed-spaces-and-tabs': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-multi-spaces': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-multiple-empty-lines': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-reserved-keys': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-space-before-semi': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-trailing-spaces': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-whitespace-before-property': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'no-wrap-func': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'nonblock-statement-body-position': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'object-curly-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'object-curly-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'object-property-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'one-var-declaration-per-line': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'operator-linebreak': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'padded-blocks': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'padding-line-between-statements': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'quote-props': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'rest-spread-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'semi': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'semi-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'semi-style': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-after-function-name': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-after-keywords': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-before-blocks': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-before-function-paren': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-before-function-parentheses': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-before-keywords': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-in-brackets': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-in-parens': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-infix-ops': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-return-throw-case': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-unary-ops': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'space-unary-word-ops': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'switch-colon-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'template-curly-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'template-tag-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'unicode-bom': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'wrap-iife': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'wrap-regex': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'yield-star-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        // ECMAScript 6
        'arrow-body-style': [utils_1.WARN, 'as-needed'],
        'constructor-super': utils_1.WARN,
        'no-class-assign': utils_1.WARN,
        'no-const-assign': utils_1.WARN,
        'no-dupe-class-members': utils_1.WARN,
        'no-dupe-else-if': utils_1.WARN,
        'no-new-symbol': utils_1.WARN,
        'no-restricted-exports': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'no-restricted-imports': [
            utils_1.WARN,
            {
                paths: [
                    {
                        name: 'lodash',
                        message: 'Please use brandingbrand utilities.',
                    },
                    {
                        name: 'lodash-es',
                        message: 'Please use brandingbrand utilities.',
                    },
                    {
                        name: 'fp-ts',
                        message: 'Please use brandingbrand utilities.',
                    },
                    {
                        name: 'styled-components',
                        message: 'Styled components has a large type checking cost.',
                    },
                ],
            },
        ],
        'no-this-before-super': utils_1.WARN,
        'no-useless-computed-key': utils_1.WARN,
        'no-useless-constructor': utils_1.WARN,
        'no-useless-rename': utils_1.WARN,
        'no-var': utils_1.WARN,
        'object-shorthand': [utils_1.WARN, 'always'],
        'prefer-arrow-callback': utils_1.WARN,
        'prefer-const': utils_1.WARN,
        'prefer-destructuring': utils_1.WARN,
        'prefer-numeric-literals': utils_1.WARN,
        'prefer-rest-params': utils_1.WARN,
        'prefer-spread': utils_1.WARN,
        'prefer-template': utils_1.WARN,
        'require-yield': utils_1.WARN,
        'symbol-description': utils_1.WARN,
        // plugin:eslint-comments **************************************************
        // rules URL: https://github.com/mysticatea/eslint-plugin-eslint-comments/tree/master/docs/rules
        'eslint-comments/disable-enable-pair': utils_1.WARN,
        'eslint-comments/no-aggregating-enable': utils_1.WARN,
        'eslint-comments/no-duplicate-disable': utils_1.WARN,
        'eslint-comments/no-unlimited-disable': utils_1.WARN,
        'eslint-comments/no-unused-disable': utils_1.WARN,
        'eslint-comments/no-unused-enable': utils_1.WARN,
        'eslint-comments/no-restricted-disable': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'eslint-comments/no-use': (0, utils_1.OFF)("Exceptions exist.  It's javascript, after all."),
        'eslint-comments/require-description': [utils_1.WARN, { ignore: ['eslint-enable'] }],
        // plugin:fp ***************************************************************
        // rules URL: https://github.com/jfmengels/eslint-plugin-fp#rules
        'fp/no-arguments': utils_1.WARN,
        'fp/no-class': (0, utils_1.OFF)(),
        'fp/no-delete': utils_1.WARN,
        'fp/no-events': utils_1.WARN,
        'fp/no-get-set': (0, utils_1.OFF)(),
        'fp/no-let': (0, utils_1.OFF)(),
        'fp/no-loops': (0, utils_1.OFF)(),
        'fp/no-mutating-assign': utils_1.WARN,
        'fp/no-mutating-methods': (0, utils_1.OFF)(),
        'fp/no-mutation': (0, utils_1.OFF)(),
        'fp/no-nil': (0, utils_1.OFF)(),
        'fp/no-proxy': (0, utils_1.OFF)(),
        'fp/no-rest-parameters': (0, utils_1.OFF)(),
        'fp/no-this': (0, utils_1.OFF)(),
        'fp/no-throw': (0, utils_1.OFF)(),
        'fp/no-unused-expression': (0, utils_1.OFF)(),
        'fp/no-valueof-field': (0, utils_1.OFF)(),
        // plugin:import ***********************************************************
        // rules URL: https://github.com/benmosher/eslint-plugin-import#rules
        // Static analysis
        'import/no-unresolved': [utils_1.WARN, { amd: true, commonjs: true }],
        'import/default': utils_1.WARN,
        'import/named': utils_1.WARN,
        'import/namespace': utils_1.WARN,
        'import/no-absolute-path': utils_1.WARN,
        'import/no-cycle': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-dynamic-require': utils_1.WARN,
        'import/no-internal-modules': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'import/no-relative-parent-imports': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'import/no-restricted-paths': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'import/no-self-import': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-unused-modules': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-useless-path-segments': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-webpack-loader-syntax': utils_1.WARN,
        // Helpful warnings
        'import/export': utils_1.WARN,
        'import/no-deprecated': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-extraneous-dependencies': (0, utils_1.OFF)("This rule doesn't play nice with monorepos, unfortunately"),
        'import/no-mutable-exports': utils_1.WARN,
        'import/no-named-as-default': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-named-as-default-member': utils_1.WARN,
        // Module systems
        'import/no-amd': utils_1.WARN,
        'import/no-commonjs': utils_1.WARN,
        'import/no-nodejs-modules': (0, utils_1.OFF)(),
        'import/unambiguous': (0, utils_1.BUGGY)('eslint-plugin-import:v2.21.1', "seems that this doesn't work with TypeScript (`d.ts`) definition files or ts files that only export TypeScript types."),
        // Stylistic
        'import/dynamic-import-chunkname': (0, utils_1.OFF)("It is nice to have the option to define a chunk name, but it shouldn't be required"),
        'import/exports-last': (0, utils_1.OFF)("I see no reason exports can't be sprinkled throughout the file"),
        'import/extensions': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'import/group-exports': (0, utils_1.OFF)(`tooling should easily answer the question of "what's exported from this module".  no need to do anything the IDE does for you.`),
        'import/max-dependencies': [utils_1.WARN, { max: 40 }],
        'import/no-anonymous-default-export': utils_1.WARN,
        'import/no-default-export': (0, utils_1.OFF)('Unfortunately some systems (e.g. Gatsby) hinge on usage of default exports.'),
        'import/no-named-default': utils_1.WARN,
        'import/no-named-export': (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
        'import/no-namespace': (0, utils_1.OFF)("typescript uses namespace imports - I'm not otherwise sure what the motivation for turning this off would be"),
        'import/no-unassigned-import': (0, utils_1.OFF)('there just seem to be too may places where this has to be done'),
        'import/prefer-default-export': (0, utils_1.OFF)('named exports are better (for one reason, because TypeScript can automatically import a named resource)'),
        // plugin:jsdoc ************************************************************
        // rules URL: https://github.com/gajus/eslint-plugin-jsdoc#eslint-plugin-jsdoc-rules
        'jsdoc/check-access': utils_1.WARN,
        'jsdoc/check-alignment': utils_1.WARN,
        'jsdoc/check-examples': (0, utils_1.OFF)('https://github.com/eslint/eslint/issues/14745'),
        'jsdoc/check-indentation': (0, utils_1.OFF)(),
        'jsdoc/check-line-alignment': utils_1.WARN,
        'jsdoc/check-param-names': utils_1.WARN,
        'jsdoc/check-property-names': utils_1.WARN,
        'jsdoc/check-syntax': utils_1.WARN,
        'jsdoc/check-tag-names': [
            utils_1.WARN,
            {
                definedTags: [
                    'usageNotes',
                    'publicApi',
                    'internal',
                    'platform',
                    /**
                     * TypeScript Schema JSON directives
                     *
                     * @see https://github.com/YousefED/typescript-json-schema/blob/master/api.md
                     */
                    '$id',
                    '$ref',
                    'additionalProperties',
                    'chance',
                    'examples',
                    'ignore',
                    'important',
                    'items',
                    'minimum',
                    'minItems',
                    'maximum',
                    'maxItems',
                    'nullable',
                    'title',
                    'TJS-ignore',
                    'TJS-type',
                    'TJS-format',
                    'TJS-hide',
                    'TJS-minimum',
                    'TJS-pattern',
                ],
            },
        ],
        'jsdoc/check-types': utils_1.WARN,
        'jsdoc/check-values': utils_1.WARN,
        'jsdoc/empty-tags': utils_1.WARN,
        'jsdoc/implements-on-classes': utils_1.WARN,
        'jsdoc/match-name': (0, utils_1.OFF)(),
        'jsdoc/match-description': (0, utils_1.OFF)(),
        'jsdoc/multiline-blocks': utils_1.WARN,
        'jsdoc/newline-after-description': utils_1.WARN,
        'jsdoc/no-bad-blocks': utils_1.WARN,
        'jsdoc/no-defaults': utils_1.WARN,
        'jsdoc/no-missing-syntax': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'jsdoc/no-multi-asterisks': utils_1.WARN,
        'jsdoc/no-restricted-syntax': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'jsdoc/no-types': (0, utils_1.OFF)(),
        'jsdoc/no-undefined-types': utils_1.WARN,
        'jsdoc/require-asterisk-prefix': utils_1.WARN,
        'jsdoc/require-description': utils_1.WARN,
        'jsdoc/require-description-complete-sentence': (0, utils_1.OFF)(),
        'jsdoc/require-example': (0, utils_1.OFF)(),
        'jsdoc/require-file-overview': (0, utils_1.OFF)(),
        'jsdoc/require-hyphen-before-param-description': (0, utils_1.OFF)(),
        'jsdoc/require-jsdoc': utils_1.WARN,
        'jsdoc/require-param': utils_1.WARN,
        'jsdoc/require-param-description': (0, utils_1.OFF)(`In many cases there isn't much else to
      say about a param beyond what it's name
      already communicates`),
        'jsdoc/require-param-name': utils_1.WARN,
        'jsdoc/require-param-type': utils_1.WARN,
        'jsdoc/require-property': utils_1.WARN,
        'jsdoc/require-property-description': utils_1.WARN,
        'jsdoc/require-property-name': utils_1.WARN,
        'jsdoc/require-property-type': utils_1.WARN,
        'jsdoc/require-returns': utils_1.WARN,
        'jsdoc/require-returns-check': utils_1.WARN,
        'jsdoc/require-returns-description': (0, utils_1.OFF)(`In many cases there isn't much else to
      say about a return of a function beyond
      what the name of the function already
      communicates`),
        'jsdoc/require-returns-type': utils_1.WARN,
        'jsdoc/require-throws': utils_1.WARN,
        'jsdoc/require-yields': utils_1.WARN,
        'jsdoc/require-yields-check': utils_1.WARN,
        'jsdoc/sort-tags': utils_1.WARN,
        'jsdoc/tag-lines': utils_1.WARN,
        'jsdoc/valid-types': utils_1.WARN,
        // plugin:prefer-arrow *****************************************************
        // rules URL: https://github.com/TristonJ/eslint-plugin-prefer-arrow#configuration
        'prefer-arrow/prefer-arrow-functions': [
            utils_1.WARN,
            {
                disallowPrototype: true,
                singleReturnOnly: false,
                // eslint-disable-next-line unicorn/no-keyword-prefix -- Externally Defined
                classPropertiesAllowed: false,
            },
        ],
        // plugin:no-secrets *******************************************************
        // rules URL: https://github.com/nickdeis/eslint-plugin-no-secrets
        'no-secrets/no-secrets': [utils_1.WARN, { tolerance: 6 }],
        // plugin:sonarjs ************************************************************
        // rules URL: https://github.com/SonarSource/eslint-plugin-sonarjs#rules
        'sonarjs/cognitive-complexity': [utils_1.WARN, 25],
        'sonarjs/elseif-without-else': (0, utils_1.OFF)('this conflicts with no-else-return'),
        'sonarjs/max-switch-cases': utils_1.WARN,
        'sonarjs/no-all-duplicated-branches': utils_1.WARN,
        'sonarjs/no-collapsible-if': utils_1.WARN,
        'sonarjs/no-collection-size-mischeck': utils_1.WARN,
        'sonarjs/no-duplicate-string': [utils_1.WARN, 9],
        'sonarjs/no-duplicated-branches': utils_1.WARN,
        'sonarjs/no-element-overwrite': utils_1.WARN,
        'sonarjs/no-empty-collection': utils_1.WARN,
        'sonarjs/non-existent-operator': utils_1.WARN,
        'sonarjs/no-gratuitous-expressions': utils_1.WARN,
        'sonarjs/no-extra-arguments': utils_1.WARN,
        'sonarjs/no-identical-conditions': utils_1.WARN,
        'sonarjs/no-identical-functions': utils_1.WARN,
        'sonarjs/no-identical-expressions': utils_1.WARN,
        'sonarjs/no-inverted-boolean-check': utils_1.WARN,
        'sonarjs/no-ignored-return': utils_1.WARN,
        'sonarjs/no-nested-switch': utils_1.WARN,
        'sonarjs/no-nested-template-literals': utils_1.WARN,
        'sonarjs/no-one-iteration-loop': utils_1.WARN,
        'sonarjs/no-redundant-boolean': utils_1.WARN,
        'sonarjs/no-redundant-jump': utils_1.WARN,
        'sonarjs/no-same-line-conditional': utils_1.WARN,
        'sonarjs/no-small-switch': utils_1.WARN,
        'sonarjs/no-unused-collection': utils_1.WARN,
        'sonarjs/no-use-of-empty-return-value': utils_1.WARN,
        'sonarjs/no-useless-catch': utils_1.WARN,
        'sonarjs/prefer-immediate-return': utils_1.WARN,
        'sonarjs/prefer-object-literal': utils_1.WARN,
        'sonarjs/prefer-single-boolean-return': utils_1.WARN,
        'sonarjs/prefer-while': utils_1.WARN,
        // plugin:security *********************************************************
        // rules URL: https://github.com/nodesecurity/eslint-plugin-security#rules
        'security/detect-unsafe-regex': (0, utils_1.SUCCESSOR)('unicorn/no-unsafe-regex'),
        'security/detect-disable-mustache-escape': utils_1.WARN,
        'security/detect-eval-with-expression': utils_1.WARN,
        'security/detect-non-literal-regexp': utils_1.WARN,
        'security/detect-non-literal-require': utils_1.WARN,
        'security/detect-object-injection': (0, utils_1.BUGGY)('unknown', 'Unable to determine the difference between user provided data and derived keys'),
        'security/detect-possible-timing-attacks': utils_1.WARN,
        'security/detect-pseudoRandomBytes': (0, utils_1.OFF)(),
        'security/detect-buffer-noassert': (0, utils_1.OFF)(),
        'security/detect-child-process': (0, utils_1.OFF)(),
        'security/detect-new-buffer': (0, utils_1.OFF)(),
        'security/detect-no-csrf-before-method-override': (0, utils_1.OFF)(),
        'security/detect-non-literal-fs-filename': (0, utils_1.OFF)(),
        // plugin:sort-destructure-keys *********************************************
        // rules URL: https://github.com/mthadley/eslint-plugin-sort-destructure-keys
        'sort-destructure-keys/sort-destructure-keys': utils_1.WARN,
        // plugin:ternary **********************************************************
        // rules URL: https://github.com/grayedfox/eslint-plugin-ternary#rules
        'ternary/no-dupe': utils_1.WARN,
        'ternary/no-unreachable': (0, utils_1.BUGGY)('eslint-plugin-ternary@1.0.3', 'Invalidly detects duplicates'),
        'ternary/nesting': [utils_1.WARN, { test: true, consequent: true, alternate: true, depth: 0 }],
        // plugin:unicorn **********************************************************
        // rules URL: https://github.com/sindresorhus/eslint-plugin-unicorn#rules
        'unicorn/better-regex': utils_1.WARN,
        'unicorn/catch-error-name': utils_1.WARN,
        'unicorn/consistent-destructuring': utils_1.WARN,
        'unicorn/consistent-function-scoping': [utils_1.WARN, { checkArrowFunctions: false }],
        'unicorn/custom-error-definition': (0, utils_1.OFF)('There are a few conventions for building errors and this only covers one of them making its usefulness limited'),
        'unicorn/error-message': utils_1.WARN,
        'unicorn/escape-case': utils_1.WARN,
        'unicorn/expiring-todo-comments': [utils_1.WARN, { allowWarningComments: true }],
        'unicorn/explicit-length-check': utils_1.WARN,
        'unicorn/filename-case': utils_1.WARN,
        'unicorn/import-index': utils_1.WARN,
        'unicorn/import-style': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'unicorn/new-for-builtins': utils_1.WARN,
        'unicorn/no-abusive-eslint-disable': utils_1.WARN,
        'unicorn/no-array-callback-reference': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'unicorn/no-array-for-each': utils_1.WARN,
        'unicorn/no-array-push-push': utils_1.WARN,
        'unicorn/no-array-method-this-argument': utils_1.WARN,
        'unicorn/no-array-reduce': utils_1.WARN,
        'unicorn/no-await-expression-member': utils_1.WARN,
        'unicorn/no-console-spaces': utils_1.WARN,
        'unicorn/no-document-cookie': utils_1.WARN,
        'unicorn/no-empty-file': utils_1.WARN,
        'unicorn/no-for-loop': utils_1.WARN,
        'unicorn/no-hex-escape': utils_1.WARN,
        'unicorn/no-instanceof-array': utils_1.WARN,
        'unicorn/no-invalid-remove-event-listener': utils_1.WARN,
        'unicorn/no-keyword-prefix': utils_1.WARN,
        'unicorn/no-lonely-if': utils_1.WARN,
        'unicorn/no-nested-ternary': (0, utils_1.SUCCESSOR)('ternary/nesting'),
        'unicorn/no-new-array': utils_1.WARN,
        'unicorn/no-new-buffer': utils_1.WARN,
        'unicorn/no-null': (0, utils_1.OFF)('null is often times used by third party libraries like such as an ORM'),
        'unicorn/no-object-as-default-parameter': utils_1.WARN,
        'unicorn/no-process-exit': utils_1.WARN,
        'unicorn/no-static-only-class': utils_1.WARN,
        'unicorn/no-thenable': utils_1.WARN,
        'unicorn/no-this-assignment': utils_1.WARN,
        'unicorn/no-unreadable-array-destructuring': utils_1.WARN,
        'unicorn/no-unreadable-iife': utils_1.WARN,
        'unicorn/no-unsafe-regex': utils_1.WARN,
        'unicorn/no-unused-properties': utils_1.WARN,
        'unicorn/no-useless-fallback-in-spread': utils_1.WARN,
        'unicorn/no-useless-length-check': utils_1.WARN,
        'unicorn/no-useless-promise-resolve-reject': utils_1.WARN,
        'unicorn/no-useless-spread': utils_1.WARN,
        'unicorn/no-useless-switch-case': utils_1.WARN,
        'unicorn/no-useless-undefined': (0, utils_1.OFF)('While this is a good idea for consistency, it conflicts with `consistent-return` which I think is more important'),
        'unicorn/no-zero-fractions': utils_1.WARN,
        'unicorn/numeric-separators-style': [
            utils_1.WARN,
            {
                onlyIfContainsSeparator: false,
                // Disable through setting a really high `minimumDigits` due
                // to android runtime not support number separators at present
                hexadecimal: {
                    minimumDigits: 1000,
                    groupLength: 2,
                },
                binary: {
                    minimumDigits: 1000,
                    groupLength: 4,
                },
                octal: {
                    minimumDigits: 1000,
                    groupLength: 4,
                },
                number: {
                    minimumDigits: 1000,
                    groupLength: 3,
                },
            },
        ],
        'unicorn/prefer-at': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'unicorn/prefer-add-event-listener': utils_1.WARN,
        'unicorn/prefer-array-find': utils_1.WARN,
        'unicorn/prefer-array-flat': utils_1.WARN,
        'unicorn/prefer-array-flat-map': utils_1.WARN,
        'unicorn/prefer-array-index-of': utils_1.WARN,
        'unicorn/prefer-array-some': utils_1.WARN,
        'unicorn/prefer-code-point': utils_1.WARN,
        'unicorn/prefer-date-now': utils_1.WARN,
        'unicorn/prefer-default-parameters': utils_1.WARN,
        'unicorn/prefer-dom-node-append': utils_1.WARN,
        'unicorn/prefer-dom-node-dataset': utils_1.WARN,
        'unicorn/prefer-dom-node-remove': utils_1.WARN,
        'unicorn/prefer-dom-node-text-content': utils_1.WARN,
        'unicorn/prefer-event-target': utils_1.WARN,
        'unicorn/prefer-export-from': utils_1.WARN,
        'unicorn/prefer-includes': utils_1.WARN,
        'unicorn/prefer-json-parse-buffer': utils_1.WARN,
        'unicorn/prefer-keyboard-event-key': utils_1.WARN,
        'unicorn/prefer-logical-operator-over-ternary': utils_1.WARN,
        'unicorn/prefer-math-trunc': utils_1.WARN,
        'unicorn/prefer-modern-dom-apis': utils_1.WARN,
        'unicorn/prefer-modern-math-apis': utils_1.WARN,
        'unicorn/prefer-module': utils_1.WARN,
        'unicorn/prefer-native-coercion-functions': utils_1.WARN,
        'unicorn/prefer-negative-index': utils_1.WARN,
        'unicorn/prefer-node-protocol': (0, utils_1.OFF)('This requires a `@types/node` update upstream to support this'),
        'unicorn/prefer-number-properties': utils_1.WARN,
        'unicorn/prefer-object-from-entries': utils_1.WARN,
        'unicorn/prefer-object-has-own': utils_1.WARN,
        'unicorn/prefer-optional-catch-binding': utils_1.WARN,
        'unicorn/prefer-prototype-methods': utils_1.WARN,
        'unicorn/prefer-query-selector': utils_1.WARN,
        'unicorn/prefer-reflect-apply': utils_1.WARN,
        'unicorn/prefer-regexp-test': utils_1.WARN,
        'unicorn/prefer-set-has': utils_1.WARN,
        'unicorn/prefer-spread': utils_1.WARN,
        'unicorn/prefer-string-replace-all': (0, utils_1.OFF)(utils_1.ES2021),
        'unicorn/prefer-string-slice': utils_1.WARN,
        'unicorn/prefer-string-starts-ends-with': utils_1.WARN,
        'unicorn/prefer-string-trim-start-end': utils_1.WARN,
        'unicorn/prefer-switch': utils_1.WARN,
        'unicorn/prefer-ternary': utils_1.WARN,
        'unicorn/prefer-top-level-await': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'unicorn/prefer-type-error': utils_1.WARN,
        'unicorn/prevent-abbreviations': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'unicorn/relative-url-style': utils_1.WARN,
        'unicorn/require-array-join-separator': utils_1.WARN,
        'unicorn/require-number-to-fixed-digits-argument': utils_1.WARN,
        'unicorn/require-post-message-target-origin': utils_1.WARN,
        'unicorn/string-content': (0, utils_1.OFF)(),
        'unicorn/template-indent': utils_1.WARN,
        'unicorn/text-encoding-identifier-case': utils_1.WARN,
        'unicorn/throw-new-error': utils_1.WARN,
        // Disabled due to overlap with code formatters, eg Prettier
        'unicorn/empty-brace-spaces': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'unicorn/number-literal-case': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
    },
};
//# sourceMappingURL=base.js.map