"use strict";
const tslib_1 = require("tslib");
const base_1 = tslib_1.__importDefault(require("./base"));
const utils_1 = require("./utils");
module.exports = {
    extends: './node.js',
    env: {
        'es6': true,
        'node': true,
        'mocha': true,
        'cypress/globals': true,
    },
    plugins: ['chai-friendly', 'cypress', 'jest-formatting', 'mocha'],
    rules: {
        // plugin:eslint ***********************************************************
        // rules URL: https://github.com/eslint/eslint/tree/master/docs/rules
        'no-unused-expressions': (0, utils_1.SUCCESSOR)('chai-friendly/no-unused-expressions'),
        'max-statements': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'max-classes-per-file': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'max-lines-per-function': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:@typescript-eslint ***********************************************
        // rules URL: https://github.com/typescript-eslint/typescript-eslint/tree/master/packages/eslint-plugin
        '@typescript-eslint/unbound-method': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:fp ***************************************************************
        // rules URL: https://github.com/jfmengels/eslint-plugin-fp#rules
        'fp/no-mutation': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:sonarjs ************************************************************
        // rules URL: https://github.com/SonarSource/eslint-plugin-sonarjs#rules
        'sonarjs/no-identical-functions': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:chai-friendly ****************************************************
        // rules URL: https://github.com/ihordiachenko/eslint-plugin-chai-friendly#usage
        'chai-friendly/no-unused-expressions': base_1.default.rules['no-unused-expressions'],
        // plugin:cypress **********************************************************
        // rules URL: https://github.com/cypress-io/eslint-plugin-cypress#rules
        'cypress/no-assigning-return-values': utils_1.WARN,
        'cypress/no-unnecessary-waiting': utils_1.WARN,
        'cypress/no-async-tests': utils_1.WARN,
        'cypress/no-force': utils_1.WARN,
        'cypress/assertion-before-screenshot': utils_1.WARN,
        'cypress/require-data-selectors': utils_1.WARN,
        // plugin:jest-formatting **************************************************
        // rules URL: https://github.com/dangreenisrael/eslint-plugin-jest-formatting#rule-documentation
        'jest-formatting/padding-around-after-all-blocks': utils_1.WARN,
        'jest-formatting/padding-around-after-each-blocks': utils_1.WARN,
        'jest-formatting/padding-around-before-all-blocks': utils_1.WARN,
        'jest-formatting/padding-around-before-each-blocks': utils_1.WARN,
        'jest-formatting/padding-around-describe-blocks': utils_1.WARN,
        'jest-formatting/padding-around-expect-groups': utils_1.WARN,
        'jest-formatting/padding-around-test-blocks': utils_1.WARN,
        'jest-formatting/padding-around-all': (0, utils_1.SUCCESSOR)('jest-formatting (all _other_ rules)'),
        // plugin:mocha ************************************************************
        // rules URL: https://github.com/lo1tuma/eslint-plugin-mocha/tree/master/docs/rules#rules
        'mocha/handle-done-callback': utils_1.WARN,
        'mocha/max-top-level-suites': [utils_1.WARN, { limit: 1 }],
        'mocha/no-async-describe': utils_1.WARN,
        'mocha/no-exclusive-tests': utils_1.WARN,
        'mocha/no-exports': utils_1.WARN,
        'mocha/no-global-tests': utils_1.WARN,
        'mocha/no-hooks': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/no-hooks-for-single-case': utils_1.WARN,
        'mocha/no-identical-title': utils_1.WARN,
        'mocha/no-mocha-arrows': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/no-nested-tests': utils_1.WARN,
        'mocha/no-pending-tests': utils_1.WARN,
        'mocha/no-return-and-callback': utils_1.WARN,
        'mocha/no-return-from-async': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/no-setup-in-describe': utils_1.WARN,
        'mocha/no-sibling-hooks': utils_1.WARN,
        'mocha/no-skipped-tests': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/no-synchronous-tests': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/no-top-level-hooks': utils_1.WARN,
        'mocha/prefer-arrow-callback': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'mocha/valid-suite-description': utils_1.WARN,
        'mocha/valid-test-description': utils_1.WARN,
    },
};
//# sourceMappingURL=cypress.js.map