"use strict";
const utils_1 = require("./utils");
module.exports = {
    env: { es6: true },
    parserOptions: {
        ecmaVersion: 2020,
        ecmaFeatures: {
            impliedStrict: true,
        },
    },
    plugins: ['@typescript-eslint', 'import', 'sort-export-all'],
    rules: {
        // plugin:eslint ***********************************************************
        // rules URL: https://github.com/eslint/eslint/tree/master/docs/rules
        'no-duplicate-imports': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'sort-imports': [
            utils_1.WARN,
            {
                ignoreDeclarationSort: true,
            },
        ],
        // plugin:@typescript-eslint ***********************************************
        // rules URL: https://github.com/typescript-eslint/typescript-eslint/tree/master/packages/eslint-plugin
        '@typescript-eslint/no-duplicate-imports': utils_1.WARN,
        // plugin:import ***********************************************************
        // rules URL: https://github.com/benmosher/eslint-plugin-import#rules
        'import/first': utils_1.WARN,
        'import/newline-after-import': utils_1.WARN,
        'import/no-duplicates': (0, utils_1.SUCCESSOR)('@typescript-eslint/no-duplicate-imports'),
        'import/no-import-module-exports': utils_1.WARN,
        'import/no-relative-packages': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'import/order': [
            utils_1.WARN,
            {
                'alphabetize': {
                    order: 'asc',
                    caseInsensitive: false,
                },
                'groups': [['external', 'builtin'], 'internal', 'parent', 'sibling'],
                'newlines-between': 'always',
                'pathGroups': [
                    {
                        group: 'external',
                        pattern: '{@angular/**,@nestjs/**,react,react-native,react-*,@vue/**,vue,@ngneat/spectator,@ngneat/spectator/**}',
                        position: 'before',
                    },
                ],
                'pathGroupsExcludedImportTypes': ['react'],
            },
        ],
        // plugin:sort-export-all **************************************************
        // rules URL: https://github.com/nirtamir2/eslint-plugin-sort-export-all
        'sort-export-all/sort-export-all': utils_1.WARN,
    },
};
//# sourceMappingURL=import-order.js.map