"use strict";
const utils_1 = require("./utils");
module.exports = {
    extends: './node.js',
    env: {
        'es6': true,
        'jest': true,
        'jest/globals': true,
        'node': true,
    },
    plugins: ['jest', 'jest-dom', 'jest-formatting'],
    rules: {
        // plugin:eslint ***********************************************************
        // rules URL: https://github.com/eslint/eslint/tree/master/docs/rules
        'max-statements': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'max-classes-per-file': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'max-lines-per-function': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:@typescript-eslint ***********************************************
        // rules URL: https://github.com/typescript-eslint/typescript-eslint/tree/master/packages/eslint-plugin
        '@typescript-eslint/explicit-function-return-type': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        '@typescript-eslint/no-non-null-assertion': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        '@typescript-eslint/unbound-method': (0, utils_1.SUCCESSOR)('jest/unbound-method'),
        // plugin:fp ***************************************************************
        // rules URL: https://github.com/jfmengels/eslint-plugin-fp#rules
        'fp/no-mutation': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:sonarjs ************************************************************
        // rules URL: https://github.com/SonarSource/eslint-plugin-sonarjs#rules
        'sonarjs/no-identical-functions': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'sonarjs/no-duplicate-string': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        // plugin:jest *************************************************************
        // rules URL: https://github.com/jest-community/eslint-plugin-jest#rules
        'jest/consistent-test-it': [utils_1.WARN, { fn: 'it' }],
        'jest/expect-expect': [
            utils_1.WARN,
            {
                assertFunctionNames: [
                    'expect',
                    'spectator.expectOne',
                    'spectator.expectConcurrent',
                    'spectator.controller.expectOne',
                    'spectator.controller.expectNone',
                ],
            },
        ],
        'jest/max-expects': utils_1.WARN,
        'jest/max-nested-describe': utils_1.WARN,
        'jest/no-alias-methods': utils_1.WARN,
        'jest/no-commented-out-tests': utils_1.WARN,
        'jest/no-conditional-expect': utils_1.WARN,
        'jest/no-conditional-in-test': utils_1.WARN,
        'jest/no-deprecated-functions': utils_1.WARN,
        'jest/no-disabled-tests': (0, utils_1.OFF)('I think having the ability to use .skip is legitimate'),
        'jest/no-done-callback': (0, utils_1.OFF)('Having a `done()` callback can be useful when working with rxjs and other async interfaces that are not promises'),
        'jest/no-duplicate-hooks': utils_1.WARN,
        'jest/no-export': utils_1.WARN,
        'jest/no-focused-tests': utils_1.WARN,
        'jest/no-hooks': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'jest/no-identical-title': utils_1.WARN,
        'jest/no-if': (0, utils_1.SUCCESSOR)('jest/no-conditional-in-test'),
        'jest/no-interpolation-in-snapshots': utils_1.WARN,
        'jest/no-jasmine-globals': utils_1.WARN,
        'jest/no-jest-import': utils_1.WARN,
        'jest/no-large-snapshots': utils_1.WARN,
        'jest/no-mocks-import': utils_1.WARN,
        'jest/no-restricted-matchers': [
            utils_1.WARN,
            {
                toBeFalsy: 'Checking if a value is simply falsy does not test very much as there are many cases where this could be true.',
                toBeTruthy: 'Checking if a value is simply truthy does not test very much as there are many cases where this could be true.',
                toMatchSnapshot: 'Use `toMatchInlineSnapshot()` instead in order to make snapshot tests more manageable and reviewable by writing the snapshots inline in the test file.',
                toThrowErrorMatchingSnapshot: 'Use `toThrowErrorMatchingInlineSnapshot()` instead in order to make snapshot tests more manageable and reviewable by writing the snapshots inline in the test file.',
            },
        ],
        'jest/no-standalone-expect': utils_1.WARN,
        'jest/no-test-prefixes': utils_1.WARN,
        'jest/no-test-return-statement': utils_1.WARN,
        'jest/prefer-called-with': utils_1.WARN,
        'jest/prefer-comparison-matcher': utils_1.WARN,
        'jest/prefer-expect-assertions': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'jest/prefer-expect-resolves': utils_1.WARN,
        'jest/prefer-equality-matcher': utils_1.WARN,
        'jest/prefer-hooks-in-order': utils_1.WARN,
        'jest/prefer-hooks-on-top': utils_1.WARN,
        'jest/prefer-lowercase-title': [utils_1.WARN, { ignoreTopLevelDescribe: true }],
        'jest/prefer-mock-promise-shorthand': utils_1.WARN,
        'jest/prefer-snapshot-hint': utils_1.WARN,
        'jest/prefer-spy-on': utils_1.WARN,
        'jest/prefer-strict-equal': utils_1.WARN,
        'jest/prefer-to-be': utils_1.WARN,
        'jest/prefer-to-contain': utils_1.WARN,
        'jest/prefer-to-have-length': utils_1.WARN,
        'jest/prefer-todo': utils_1.WARN,
        'jest/require-hook': utils_1.WARN,
        'jest/require-to-throw-message': utils_1.WARN,
        'jest/require-top-level-describe': utils_1.WARN,
        'jest/unbound-method': utils_1.WARN,
        'jest/valid-describe-callback': utils_1.WARN,
        'jest/valid-expect': utils_1.WARN,
        'jest/valid-expect-in-promise': utils_1.WARN,
        'jest/valid-title': utils_1.WARN,
        // plugin:jest-dom *******************************************************
        // rules URL: https://github.com/testing-library/eslint-plugin-jest-dom#supported-rules
        'jest-dom/prefer-checked': utils_1.WARN,
        'jest-dom/prefer-empty': utils_1.WARN,
        'jest-dom/prefer-enabled-disabled': utils_1.WARN,
        'jest-dom/prefer-focus': utils_1.WARN,
        'jest-dom/prefer-in-document': utils_1.WARN,
        'jest-dom/prefer-required': utils_1.WARN,
        'jest-dom/prefer-to-have-attribute': utils_1.WARN,
        'jest-dom/prefer-to-have-class': utils_1.WARN,
        'jest-dom/prefer-to-have-style': utils_1.WARN,
        'jest-dom/prefer-to-have-text-content': utils_1.WARN,
        'jest-dom/prefer-to-have-value': utils_1.WARN,
        // plugin:jest-formatting **************************************************
        // rules URL: https://github.com/dangreenisrael/eslint-plugin-jest-formatting#rule-documentation
        'jest-formatting/padding-around-after-all-blocks': utils_1.WARN,
        'jest-formatting/padding-around-after-each-blocks': utils_1.WARN,
        'jest-formatting/padding-around-before-all-blocks': utils_1.WARN,
        'jest-formatting/padding-around-before-each-blocks': utils_1.WARN,
        'jest-formatting/padding-around-describe-blocks': utils_1.WARN,
        'jest-formatting/padding-around-expect-groups': utils_1.WARN,
        'jest-formatting/padding-around-test-blocks': utils_1.WARN,
        'jest-formatting/padding-around-all': (0, utils_1.SUCCESSOR)('jest-formatting (all _other_ rules)'),
        // plugin:rxjs **************************************************************
        // rules URL: https://github.com/cartant/eslint-plugin-rxjs
        'rxjs/no-ignored-subscribe': (0, utils_1.OFF)('Subscriptions are typically very short lived in test'),
    },
};
//# sourceMappingURL=jest.js.map