"use strict";
const utils_1 = require("./utils");
module.exports = {
    env: {
        browser: true,
        es6: true,
    },
    settings: {
        react: {
            version: 'detect',
        },
    },
    plugins: ['jsx-a11y', 'react', 'react-hooks', 'react-perf', 'react-redux'],
    rules: {
        // plugin:jsx-a11y *********************************************************
        // rules URL: https://github.com/jsx-eslint/eslint-plugin-jsx-a11y#supported-rules
        'jsx-a11y/accessible-emoji': utils_1.WARN,
        'jsx-a11y/alt-text': utils_1.WARN,
        'jsx-a11y/anchor-has-content': utils_1.WARN,
        'jsx-a11y/anchor-is-valid': [
            utils_1.WARN,
            {
                aspects: ['noHref', 'invalidHref'],
            },
        ],
        'jsx-a11y/aria-activedescendant-has-tabindex': utils_1.WARN,
        'jsx-a11y/aria-props': utils_1.WARN,
        'jsx-a11y/aria-proptypes': utils_1.WARN,
        'jsx-a11y/aria-role': [utils_1.WARN, { ignoreNonDOM: true }],
        'jsx-a11y/aria-unsupported-elements': utils_1.WARN,
        'jsx-a11y/autocomplete-valid': utils_1.WARN,
        'jsx-a11y/click-events-have-key-events': utils_1.WARN,
        'jsx-a11y/control-has-associated-label': [
            (0, utils_1.OFF)(),
            {
                ignoreElements: ['audio', 'canvas', 'embed', 'input', 'textarea', 'tr', 'video'],
                ignoreRoles: [
                    'grid',
                    'listbox',
                    'menu',
                    'menubar',
                    'radiogroup',
                    'row',
                    'tablist',
                    'toolbar',
                    'tree',
                    'treegrid',
                ],
                includeRoles: ['alert', 'dialog'],
            },
        ],
        'jsx-a11y/heading-has-content': utils_1.WARN,
        'jsx-a11y/html-has-lang': utils_1.WARN,
        'jsx-a11y/iframe-has-title': utils_1.WARN,
        'jsx-a11y/img-redundant-alt': utils_1.WARN,
        'jsx-a11y/interactive-supports-focus': [
            utils_1.WARN,
            {
                tabbable: [
                    'button',
                    'checkbox',
                    'link',
                    'progressbar',
                    'searchbox',
                    'slider',
                    'spinbutton',
                    'switch',
                    'textbox',
                ],
            },
        ],
        'jsx-a11y/label-has-associated-control': utils_1.WARN,
        'jsx-a11y/label-has-for': (0, utils_1.OFF)(),
        'jsx-a11y/lang': utils_1.WARN,
        'jsx-a11y/media-has-caption': utils_1.WARN,
        'jsx-a11y/mouse-events-have-key-events': utils_1.WARN,
        'jsx-a11y/no-access-key': utils_1.WARN,
        'jsx-a11y/no-autofocus': utils_1.WARN,
        'jsx-a11y/no-distracting-elements': utils_1.WARN,
        'jsx-a11y/no-interactive-element-to-noninteractive-role': utils_1.WARN,
        'jsx-a11y/no-noninteractive-element-interactions': [
            utils_1.WARN,
            {
                body: ['onError', 'onLoad'],
                iframe: ['onError', 'onLoad'],
                img: ['onError', 'onLoad'],
            },
        ],
        'jsx-a11y/no-noninteractive-element-to-interactive-role': utils_1.WARN,
        'jsx-a11y/no-noninteractive-tabindex': utils_1.WARN,
        'jsx-a11y/no-redundant-roles': utils_1.WARN,
        'jsx-a11y/no-static-element-interactions': utils_1.WARN,
        'jsx-a11y/role-has-required-aria-props': utils_1.WARN,
        'jsx-a11y/role-supports-aria-props': utils_1.WARN,
        'jsx-a11y/scope': utils_1.WARN,
        'jsx-a11y/tabindex-no-positive': utils_1.ERROR,
        // plugin:react ************************************************************
        // rules URL: https://github.com/yannickcr/eslint-plugin-react/tree/master/docs/rules
        'react/boolean-prop-naming': [
            (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
            { rule: '^(is|should|has|can|did|will)[A-Z]([A-Za-z0-9]?)+' },
        ],
        'react/button-has-type': utils_1.WARN,
        'react/default-props-match-prop-types': (0, utils_1.OFF)('#ProptypesAreDead'),
        // TODO (@wSedlacek) [eslint-plugin-react@>=7.31.0]: Enable after discussion
        'react/destructuring-assignment': [
            (0, utils_1.OFF)(utils_1.LARGE_PERFORMANCE_COST),
            'always',
            { destructureInSignature: 'always' },
        ],
        'react/display-name': (0, utils_1.OFF)('The problem with this rule is that errors on stateless functional components called as functions (not components) e.g. `renderThings(props)` and not `<RenderThings {...props} />`.'),
        'react/forbid-component-props': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'react/forbid-dom-props': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'react/forbid-elements': (0, utils_1.OFF)(utils_1.PROJECT_BY_PROJECT),
        'react/forbid-foreign-prop-types': [utils_1.WARN, { allowInPropTypes: true }],
        'react/forbid-prop-types': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'react/function-component-definition': [
            utils_1.WARN,
            {
                namedComponents: 'arrow-function',
                unnamedComponents: 'arrow-function',
            },
        ],
        'react/hook-use-state': utils_1.WARN,
        'react/iframe-missing-sandbox': utils_1.WARN,
        'react/no-access-state-in-setstate': utils_1.WARN,
        'react/no-adjacent-inline-elements': (0, utils_1.OFF)(utils_1.NOT_VALUABLE),
        'react/no-array-index-key': utils_1.WARN,
        'react/no-arrow-function-lifecycle': utils_1.WARN,
        'react/no-children-prop': utils_1.WARN,
        'react/no-danger': utils_1.WARN,
        'react/no-danger-with-children': utils_1.WARN,
        'react/no-deprecated': utils_1.WARN,
        'react/no-did-mount-set-state': [utils_1.WARN, 'disallow-in-func'],
        'react/no-did-update-set-state': [utils_1.WARN, 'disallow-in-func'],
        'react/no-direct-mutation-state': utils_1.WARN,
        'react/no-find-dom-node': utils_1.WARN,
        'react/no-is-mounted': utils_1.WARN,
        'react/no-invalid-html-attribute': utils_1.WARN,
        'react/no-namespace': utils_1.WARN,
        'react/no-multi-comp': (0, utils_1.OFF)("I find this pattern useful. It's one of those things that needs to be left up to discretion."),
        'react/no-redundant-should-component-update': utils_1.WARN,
        'react/no-render-return-value': utils_1.WARN,
        'react/no-set-state': (0, utils_1.OFF)("While enabling this rule should be most project's goal, it's not always ideal (for fast and frequently updating UI, for example) to go through redux for _every_ single thing."),
        'react/no-string-refs': utils_1.WARN,
        'react/no-this-in-sfc': utils_1.WARN,
        'react/no-typos': utils_1.ERROR,
        'react/no-unescaped-entities': utils_1.WARN,
        'react/no-unstable-nested-components': utils_1.WARN,
        'react/no-unknown-property': utils_1.WARN,
        'react/no-unsafe': utils_1.WARN,
        'react/no-unused-class-component-methods': utils_1.WARN,
        'react/no-unused-prop-types': utils_1.WARN,
        'react/no-unused-state': utils_1.WARN,
        'react/no-will-update-set-state': [utils_1.WARN, 'disallow-in-func'],
        'react/prefer-es6-class': utils_1.WARN,
        'react/prefer-exact-props': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'react/prefer-read-only-props': utils_1.WARN,
        'react/prefer-stateless-function': utils_1.WARN,
        'react/prop-types': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'react/react-in-jsx-scope': utils_1.WARN,
        'react/require-default-props': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'react/require-optimization': (0, utils_1.OFF)("This rule makes sense if you weren't depending on redux and things like reselect and re-reselect like I often do."),
        'react/require-render-return': utils_1.ERROR,
        'react/self-closing-comp': utils_1.WARN,
        'react/sort-comp': (0, utils_1.OFF)('Now that hooks are a thing this is far less useful than it used to be'),
        'react/sort-prop-types': utils_1.WARN,
        'react/state-in-constructor': [utils_1.WARN, 'never'],
        'react/static-property-placement': utils_1.WARN,
        'react/style-prop-object': utils_1.WARN,
        'react/void-dom-elements-no-children': utils_1.WARN,
        // JSX rules
        'react/jsx-boolean-value': utils_1.WARN,
        'react/jsx-curly-brace-presence': utils_1.WARN,
        'react/jsx-filename-extension': [utils_1.WARN, { extensions: ['.jsx', '.tsx'] }],
        'react/jsx-fragments': [utils_1.WARN, 'element'],
        'react/jsx-handler-names': utils_1.WARN,
        'react/jsx-key': utils_1.WARN,
        'react/jsx-max-depth': [utils_1.WARN, { max: 15 }],
        'react/jsx-no-bind': [utils_1.WARN, { ignoreRefs: true }],
        'react/jsx-no-comment-textnodes': utils_1.WARN,
        'react/jsx-no-constructed-context-values': utils_1.WARN,
        'react/jsx-no-duplicate-props': utils_1.WARN,
        'react/jsx-no-leaked-render': utils_1.WARN,
        'react/jsx-no-literals': (0, utils_1.OFF)("yeah... this rule shouldn't exist - we should just fix the syntax highlighters."),
        'react/jsx-no-script-url': utils_1.WARN,
        'react/jsx-no-target-blank': utils_1.WARN,
        'react/jsx-no-undef': utils_1.ERROR,
        'react/jsx-no-useless-fragment': utils_1.WARN,
        'react/jsx-pascal-case': utils_1.WARN,
        'react/jsx-props-no-spreading': [utils_1.WARN, { custom: 'ignore' }],
        'react/jsx-sort-default-props': utils_1.WARN,
        'react/jsx-sort-props': utils_1.WARN,
        'react/jsx-uses-react': (0, utils_1.SUCCESSOR)('no-unused-vars'),
        'react/jsx-uses-vars': (0, utils_1.SUCCESSOR)('no-unused-vars'),
        // Disabled due to overlap with code formatters, eg Prettier
        'react/jsx-child-element-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-closing-bracket-location': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-closing-tag-location': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-curly-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-curly-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-equals-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-first-prop-new-line': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-indent': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-indent-props': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-max-props-per-line': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-newline': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-one-expression-per-line': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-props-no-multi-spaces': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-tag-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        'react/jsx-wrap-multilines': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        // plugin:react-hooks ******************************************************
        // rules URL: https://github.com/facebook/react/tree/master/packages/eslint-plugin-react-hooks
        'react-hooks/exhaustive-deps': utils_1.WARN,
        'react-hooks/rules-of-hooks': utils_1.WARN,
        // plugin:react-perf *******************************************************
        // rules URL: https://github.com/cvazac/eslint-plugin-react-perf#list-of-supported-rules
        'react-perf/jsx-no-new-object-as-prop': utils_1.WARN,
        'react-perf/jsx-no-new-array-as-prop': utils_1.WARN,
        'react-perf/jsx-no-new-function-as-prop': (0, utils_1.SUCCESSOR)('react/jsx-no-bind'),
        'react-perf/jsx-no-jsx-as-prop': utils_1.WARN,
        // plugin:react-redux ******************************************************
        // rules URL: https://github.com/DianaSuvorova/eslint-plugin-react-redux#supported-rules
        'react-redux/connect-prefer-minimum-two-arguments': (0, utils_1.OFF)(),
        'react-redux/connect-prefer-named-arguments': utils_1.WARN,
        'react-redux/mapDispatchToProps-prefer-parameters-names': utils_1.WARN,
        'react-redux/mapDispatchToProps-prefer-shorthand': utils_1.WARN,
        'react-redux/mapDispatchToProps-returns-object': utils_1.WARN,
        'react-redux/mapStateToProps-no-store': utils_1.WARN,
        'react-redux/mapStateToProps-prefer-hoisted': utils_1.WARN,
        'react-redux/mapStateToProps-prefer-parameters-names': utils_1.WARN,
        'react-redux/mapStateToProps-prefer-selectors': utils_1.WARN,
        'react-redux/no-unused-prop-types': (0, utils_1.SUCCESSOR)('react/no-unused-prop-types'),
        'react-redux/prefer-separate-component-file': utils_1.WARN,
        'react-redux/useSelector-prefer-selectors': utils_1.WARN,
        // plugin:unicorn **********************************************************
        // rules URL: https://github.com/sindresorhus/eslint-plugin-unicorn#rules
        'unicorn/no-null': (0, utils_1.OFF)('Return values of render functions may need to be null'),
    },
};
//# sourceMappingURL=react.js.map