"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const child_process_1 = require("child_process");
const tree_1 = require("nx/src/generators/tree");
const path_1 = require("path");
const merge_project_configuration_util_1 = require("../../utils/merge-project-configuration.util");
const runExecutor = (_options, context) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve) => {
        const { isVerbose, projectName, root } = context;
        if (projectName === undefined) {
            devkit_1.logger.error('Executor MUST be run on a project but no project name was found');
            resolve({ success: false });
            return;
        }
        const fileName = `max-warnings.json`;
        const outputFile = (0, path_1.join)('dist', 'eslint-config', projectName, fileName);
        devkit_1.logger.info(`Running linting for ${projectName} to get current warning count...`);
        const subProcess = (0, child_process_1.spawnSync)('nx', [
            'lint',
            projectName,
            '--skip-nx-cache',
            '--format=json',
            `--output-file=${outputFile}`,
            '--max-warnings=-1',
        ], {
            stdio: 'ignore',
        });
        if (subProcess.error) {
            devkit_1.logger.error('Failed to lint project');
            resolve({ success: false });
            return;
        }
        const tree = new tree_1.FsTree(root, isVerbose);
        const results = (0, devkit_1.readJson)(tree, outputFile);
        const totalWarnings = results.reduce((total, result) => total + result.warningCount, 0);
        devkit_1.logger.info(`Setting max warnings for ${projectName} to current warning count of ${totalWarnings}`);
        (0, merge_project_configuration_util_1.mergeProjectConfiguration)(tree, projectName, {
            targets: {
                lint: {
                    executor: '@nrwl/linter:eslint',
                    outputs: ['{options.outputFile}'],
                    options: {
                        maxWarnings: totalWarnings,
                    },
                },
            },
        });
        (0, tree_1.flushChanges)(root, tree.listChanges());
        resolve({ success: true });
    });
});
exports.default = runExecutor;
//# sourceMappingURL=executor.js.map