"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const path_1 = tslib_1.__importDefault(require("path"));
const merge_project_configuration_util_1 = require("../../utils/merge-project-configuration.util");
const normalizeOptions = (tree, options) => {
    const { root: projectRoot, targets } = (0, devkit_1.readProjectConfiguration)(tree, options.projectName);
    const defaultProjectPaths = [`${projectRoot}/tsconfig.json`];
    const cypressProjectPaths = [`${projectRoot}/tsconfig.json`, `${projectRoot}/tsconfig.*?.json`];
    const tsConfigPaths = options.testing === "cypress" /* Testing.Cypress */ ? defaultProjectPaths : cypressProjectPaths;
    const typeScriptExtensions = options.framework === "react" /* Framework.React */ || options.framework === "react-native" /* Framework.ReactNative */
        ? ['ts', 'tsx']
        : ['ts'];
    const javaScriptExtensions = options.framework === "react" /* Framework.React */ || options.framework === "react-native" /* Framework.ReactNative */
        ? ['js', 'jsx']
        : ['js'];
    const typeScriptPlugins = [
        `brandingbrand/${options.language}`,
        ...(options.framework !== "none" /* Framework.None */ ? [`brandingbrand/${options.framework}`] : []),
        ...options.libraries.map((library) => `brandingbrand/${library}`),
    ];
    const overrides = [
        {
            extends: typeScriptPlugins,
            files: typeScriptExtensions.map((extension) => `*.${extension}`),
            parserOptions: { project: tsConfigPaths },
            rules: {},
        },
        ...(options.testing !== "none" /* Testing.None */
            ? [
                {
                    extends: `brandingbrand/${options.testing}`,
                    files: typeScriptExtensions.map((extension) => `*.spec.${extension}`),
                    rules: {},
                },
            ]
            : []),
        ...('storybook' in (targets !== null && targets !== void 0 ? targets : {})
            ? [
                {
                    extends: `brandingbrand/storybook`,
                    files: typeScriptExtensions.flatMap((extension) => [
                        `*.story.${extension}`,
                        `*.stories.${extension}`,
                    ]),
                    rules: {},
                },
            ]
            : []),
    ];
    return Object.assign(Object.assign({}, options), { overrides, extensions: [...typeScriptExtensions, ...javaScriptExtensions], projectRoot });
};
const addEslintRc = (tree, options) => {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.projectName)), { offsetFromRoot: (0, devkit_1.offsetFromRoot)(options.projectRoot) });
    // eslint-disable-next-line unicorn/prefer-module -- import.meta requires es2020 imports
    (0, devkit_1.generateFiles)(tree, path_1.default.join(__dirname, 'files'), options.projectRoot, templateOptions);
};
const runGenerator = (tree, options) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const normalizedOptions = normalizeOptions(tree, options);
    addEslintRc(tree, normalizedOptions);
    (0, merge_project_configuration_util_1.mergeProjectConfiguration)(tree, options.projectName, {
        targets: {
            'lint': {
                executor: '@nrwl/linter:eslint',
                outputs: ['{options.outputFile}'],
                options: {
                    lintFilePatterns: [
                        `${normalizedOptions.projectRoot}/**/*.{${normalizedOptions.extensions.join(',')}}`,
                    ],
                    hasTypeAwareRules: true,
                },
            },
            'set-max-warnings': {
                executor: 'eslint-config-brandingbrand:set-max-warnings',
            },
        },
    });
    yield (0, devkit_1.formatFiles)(tree);
});
exports.default = runGenerator;
//# sourceMappingURL=generator.js.map