"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeDeep = void 0;
const mergeDeep = (...objects) => {
    const isObject = (obj) => Boolean(obj !== null && typeof obj === 'object');
    const deepMergeInner = (target, source) => {
        for (const key of Object.keys(source)) {
            const targetValue = target[key];
            const sourceValue = source[key];
            if (Array.isArray(targetValue) && Array.isArray(sourceValue)) {
                target[key] = sourceValue;
            }
            else if (isObject(targetValue) && isObject(sourceValue)) {
                target[key] = deepMergeInner(Object.assign({}, targetValue), sourceValue);
            }
            else {
                target[key] = sourceValue;
            }
        }
        return target;
    };
    if (objects.length < 2) {
        throw new Error('deepMerge: this function expects at least 2 objects to be provided');
    }
    if (objects.some((object) => !isObject(object))) {
        throw new Error('deepMerge: all values should be of type "object"');
    }
    const target = {};
    for (const source of objects) {
        deepMergeInner(target, source);
    }
    return target;
};
exports.mergeDeep = mergeDeep;
//# sourceMappingURL=merge-deep.util.js.map