"use strict";
const tslib_1 = require("tslib");
const base_1 = tslib_1.__importDefault(require("./base"));
const utils_1 = require("./utils");
module.exports = {
    extends: './base.js',
    parser: '@typescript-eslint/parser',
    plugins: ['@typescript-eslint'],
    rules: {
        // plugin:eslint ***********************************************************
        // rules URL: https://github.com/eslint/eslint/tree/master/docs/rules
        // Disabled because TypeScript inherently checks
        'strict': [utils_1.ERROR, 'never'],
        'constructor-super': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'getter-return': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-const-assign': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-dupe-args': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-dupe-keys': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-func-assign': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-new-symbol': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-obj-calls': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-this-before-super': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-undef': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-unreachable': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'no-unsafe-negation': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'valid-typeof': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        // Disabled because @typescript-eslint extends the rule
        'brace-style': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'camelcase': (0, utils_1.SUCCESSOR)('@typescript-eslint/naming-convention'),
        'default-param-last': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'dot-notation': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'init-declarations': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-dupe-class-members': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-extra-parens': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-extra-semi': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-loss-of-precision': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-empty-function': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-implied-eval': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-invalid-this': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-loop-func': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-magic-numbers': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-redeclare': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-shadow': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-throw-literal': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-unused-expressions': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-unused-vars': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-use-before-define': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'comma-dangle': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'comma-spacing': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'func-call-spacing': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'indent': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'keyword-spacing': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'lines-between-class-members': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-array-constructor': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-duplicate-imports': (0, utils_1.SUCCESSOR)('@typescript-eslint/no-duplicate-imports'),
        'no-restricted-imports': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'no-useless-constructor': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'object-curly-spacing': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'padding-line-between-statements': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'quotes': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'require-await': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'semi': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'space-before-blocks': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'space-before-function-paren': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        'space-infix-ops': (0, utils_1.OFF)(utils_1.TYPESCRIPT_EXTENDED),
        // plugin:import ***********************************************************
        // rules URL: https://github.com/benmosher/eslint-plugin-import#rules
        'import/named': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'import/namespace': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'import/default': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'import/no-named-as-default-member': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'import/no-unresolved': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        // plugin:jsdoc ************************************************************
        // rules URL: https://github.com/gajus/eslint-plugin-jsdoc#eslint-plugin-jsdoc-rules
        'jsdoc/no-types': utils_1.WARN,
        'jsdoc/no-undefined-types': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'jsdoc/require-param-type': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        'jsdoc/require-returns-type': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        // plugin:@typescript-eslint ***********************************************
        // rules URL: https://github.com/typescript-eslint/typescript-eslint/tree/master/packages/eslint-plugin
        // extension rules
        '@typescript-eslint/brace-style': base_1.default.rules['brace-style'],
        '@typescript-eslint/comma-dangle': base_1.default.rules['comma-dangle'],
        '@typescript-eslint/comma-spacing': base_1.default.rules['comma-spacing'],
        '@typescript-eslint/default-param-last': base_1.default.rules['default-param-last'],
        '@typescript-eslint/dot-notation': base_1.default.rules['dot-notation'],
        '@typescript-eslint/func-call-spacing': base_1.default.rules['func-call-spacing'],
        '@typescript-eslint/indent': base_1.default.rules.indent,
        '@typescript-eslint/init-declarations': base_1.default.rules['init-declarations'],
        '@typescript-eslint/keyword-spacing': base_1.default.rules['keyword-spacing'],
        '@typescript-eslint/lines-between-class-members': base_1.default.rules['lines-between-class-members'],
        '@typescript-eslint/no-array-constructor': base_1.default.rules['no-array-constructor'],
        '@typescript-eslint/no-dupe-class-members': (0, utils_1.OFF)(utils_1.TYPESCRIPT),
        '@typescript-eslint/no-duplicate-imports': base_1.default.rules['no-duplicate-imports'],
        '@typescript-eslint/no-empty-function': base_1.default.rules['no-empty-function'],
        '@typescript-eslint/no-extra-parens': base_1.default.rules['no-extra-parens'],
        '@typescript-eslint/no-extra-semi': base_1.default.rules['no-extra-semi'],
        '@typescript-eslint/no-implied-eval': base_1.default.rules['no-implied-eval'],
        '@typescript-eslint/no-invalid-this': base_1.default.rules['no-invalid-this'],
        '@typescript-eslint/no-loop-func': base_1.default.rules['no-loop-func'],
        '@typescript-eslint/no-loss-of-precision': base_1.default.rules['no-loss-of-precision'],
        '@typescript-eslint/no-magic-numbers': base_1.default.rules['no-magic-numbers'],
        '@typescript-eslint/no-redeclare': base_1.default.rules['no-redeclare'],
        '@typescript-eslint/no-restricted-imports': base_1.default.rules['no-restricted-imports'],
        '@typescript-eslint/no-shadow': base_1.default.rules['no-shadow'],
        '@typescript-eslint/no-throw-literal': base_1.default.rules['no-throw-literal'],
        '@typescript-eslint/no-unused-expressions': base_1.default.rules['no-unused-expressions'],
        '@typescript-eslint/no-unused-vars': base_1.default.rules['no-unused-vars'],
        '@typescript-eslint/no-use-before-define': base_1.default.rules['no-use-before-define'],
        '@typescript-eslint/no-useless-constructor': base_1.default.rules['no-useless-constructor'],
        '@typescript-eslint/object-curly-spacing': base_1.default.rules['object-curly-spacing'],
        '@typescript-eslint/padding-line-between-statements': base_1.default.rules['padding-line-between-statements'],
        '@typescript-eslint/quotes': base_1.default.rules.quotes,
        '@typescript-eslint/require-await': base_1.default.rules['require-await'],
        '@typescript-eslint/return-await': base_1.default.rules['no-return-await'],
        '@typescript-eslint/semi': base_1.default.rules.semi,
        '@typescript-eslint/space-before-blocks': base_1.default.rules['space-before-blocks'],
        '@typescript-eslint/space-before-function-paren': base_1.default.rules['space-before-function-paren'],
        '@typescript-eslint/space-infix-ops': base_1.default.rules['space-infix-ops'],
        // Possible Errors
        '@typescript-eslint/adjacent-overload-signatures': utils_1.WARN,
        '@typescript-eslint/array-type': [utils_1.WARN, { default: 'array-simple' }],
        '@typescript-eslint/await-thenable': utils_1.WARN,
        '@typescript-eslint/ban-ts-comment': [
            utils_1.WARN,
            {
                'ts-expect-error': 'allow-with-description',
                'ts-ignore': 'allow-with-description',
            },
        ],
        '@typescript-eslint/ban-tslint-comment': utils_1.WARN,
        '@typescript-eslint/ban-types': (0, utils_1.BUGGY)('@typescript-eslint/eslint-plugin:^4.20.0', "It would be nice to ban certain types, however there doesn't appear to be an option to disable the default disabled types"),
        '@typescript-eslint/class-literal-property-style': utils_1.WARN,
        '@typescript-eslint/consistent-generic-constructors': utils_1.WARN,
        '@typescript-eslint/consistent-indexed-object-style': utils_1.WARN,
        '@typescript-eslint/consistent-type-assertions': [
            utils_1.WARN,
            {
                assertionStyle: 'as',
                objectLiteralTypeAssertions: 'allow-as-parameter',
            },
        ],
        '@typescript-eslint/consistent-type-definitions': [utils_1.WARN, 'interface'],
        '@typescript-eslint/consistent-type-exports': utils_1.WARN,
        '@typescript-eslint/consistent-type-imports': [
            utils_1.WARN,
            { prefer: 'type-imports', disallowTypeAnnotations: true },
        ],
        '@typescript-eslint/explicit-function-return-type': [
            utils_1.WARN,
            {
                allowExpressions: true,
                allowHigherOrderFunctions: true,
                allowTypedFunctionExpressions: true,
                allowDirectConstAssertionInArrowFunctions: true,
                allowConciseArrowFunctionExpressionsStartingWithVoid: true,
            },
        ],
        '@typescript-eslint/explicit-member-accessibility': [
            utils_1.WARN,
            {
                accessibility: 'explicit',
                overrides: {
                    accessors: 'explicit',
                    constructors: 'no-public',
                    methods: 'explicit',
                    properties: 'explicit',
                    parameterProperties: 'explicit',
                },
            },
        ],
        '@typescript-eslint/explicit-module-boundary-types': (0, utils_1.OFF)('I prefer to rely on type inference as much as possible.'),
        '@typescript-eslint/member-delimiter-style': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        '@typescript-eslint/member-ordering': [
            utils_1.WARN,
            {
                default: [
                    'signature',
                    'static-field',
                    'private-static-method',
                    'protected-static-method',
                    'public-static-method',
                    'private-constructor',
                    'protected-constructor',
                    'public-constructor',
                    /**
                     * Field initialization can depend on each other
                     * for example a private field that depends on a public
                     * filed of vice versa.
                     */
                    'field',
                    'private-method',
                    'protected-method',
                    'public-method',
                ],
            },
        ],
        '@typescript-eslint/method-signature-style': utils_1.WARN,
        '@typescript-eslint/naming-convention': [
            utils_1.WARN,
            {
                selector: ['memberLike'],
                format: ['camelCase', 'PascalCase'],
                filter: {
                    regex: '^Content-Type$',
                    match: false,
                },
                /**
                 * Using leading underscores to denote private members is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * In TypeScript we have member access modifiers in classes
                 * which can provide design time privacy, and for true privacy
                 * ES2019 Private Members can be leveraged.
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['variableLike'],
                format: ['camelCase'],
                /**
                 * Using leading underscores to denote private variables is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * Use symbols, reflection or other true private mechanism to
                 * ensure true privacy.
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['parameter'],
                format: ['camelCase'],
                /**
                 * A leading underscore when used with a parameter denotes
                 * that the parameter is not used internally by the function
                 *
                 * This is often times used to build functions that follow
                 * a certain interface for interoperability despite a specific
                 * implementation not needing all the parameters provided.
                 */
                leadingUnderscore: 'allow',
            },
            {
                selector: ['variable'],
                types: ['boolean'],
                format: ['PascalCase'],
                prefix: ['is', 'should', 'has', 'can', 'did', 'will', 'does'],
                /**
                 * Using leading underscores to denote private variables is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * Use symbols, reflection or other true private mechanism to
                 * ensure true privacy.
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['variable'],
                format: ['camelCase', 'UPPER_CASE', 'PascalCase'],
                /**
                 * Using leading underscores to denote private variables is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * Use symbols, reflection or other true private mechanism to
                 * ensure true privacy.
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['function'],
                format: ['camelCase'],
                /**
                 * Using leading underscores to denote private variables is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * Use symbols, reflection or other true private mechanism to
                 * ensure true privacy.
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['typeParameter'],
                format: ['PascalCase'],
                custom: {
                    regex: '^([A-Z][a-z](([A-Z]|[a-z])*[a-z])?)?([A-Z]|Type)$',
                    match: true,
                },
                /**
                 * Unlike parameters, type parameters are either inferred or
                 * explicitly defined. They cannot be defined such that they
                 * are compatible with an interface.
                 *
                 * To that end, there is no valid use case for an unused type
                 * parameter
                 */
                leadingUnderscore: 'forbid',
            },
            {
                selector: ['interface'],
                format: ['PascalCase'],
                /**
                 * Using leading underscores to denote private interfaces is an
                 * anti-pattern. This provides the illusion of privacy despite
                 * in many cases external systems being built on top of that
                 * implementation.
                 *
                 * Use `@internal` jsdocs and exclusive exports to keep
                 * an interface internal to a specific library
                 *
                 * @see https://www.hyrumslaw.com
                 */
                leadingUnderscore: 'forbid',
            },
            /**
             * Variable naming on destructuring is outside of the control of
             * the one destructuring. While we could rename the values, the
             * warnings are caught further upstream and it would be best they
             * are dealt with at their source.
             */
            {
                selector: 'variable',
                modifiers: ['destructured'],
                format: null,
            },
        ],
        '@typescript-eslint/no-base-to-string': utils_1.WARN,
        '@typescript-eslint/no-confusing-non-null-assertion': utils_1.WARN,
        '@typescript-eslint/no-confusing-void-expression': utils_1.WARN,
        '@typescript-eslint/no-duplicate-enum-values': utils_1.WARN,
        '@typescript-eslint/no-dynamic-delete': utils_1.WARN,
        '@typescript-eslint/no-empty-interface': (0, utils_1.OFF)('Often has legitimate use when mocking out an API or showing intent'),
        '@typescript-eslint/no-explicit-any': [utils_1.WARN, { fixToUnknown: false, ignoreRestArgs: true }],
        '@typescript-eslint/no-extra-non-null-assertion': utils_1.WARN,
        '@typescript-eslint/no-extraneous-class': [
            utils_1.WARN,
            { allowWithDecorator: true, allowConstructorOnly: true },
        ],
        '@typescript-eslint/no-floating-promises': utils_1.WARN,
        '@typescript-eslint/no-for-in-array': utils_1.WARN,
        '@typescript-eslint/no-implicit-any-catch': (0, utils_1.SUCCESSOR)('tsconfig.compilerOptions.strict'),
        '@typescript-eslint/no-inferrable-types': utils_1.WARN,
        '@typescript-eslint/no-invalid-void-type': utils_1.WARN,
        '@typescript-eslint/no-meaningless-void-operator': utils_1.WARN,
        '@typescript-eslint/no-misused-new': utils_1.ERROR,
        '@typescript-eslint/no-misused-promises': utils_1.WARN,
        '@typescript-eslint/no-namespace': [utils_1.WARN, { allowDeclarations: true }],
        '@typescript-eslint/no-non-null-asserted-optional-chain': utils_1.WARN,
        '@typescript-eslint/no-non-null-asserted-nullish-coalescing': utils_1.WARN,
        '@typescript-eslint/no-non-null-assertion': utils_1.WARN,
        '@typescript-eslint/no-parameter-properties': (0, utils_1.OFF)('Parameter properties help clean up constructors and are particularly useful with dependency injection'),
        '@typescript-eslint/no-redundant-type-constituents': utils_1.WARN,
        '@typescript-eslint/no-require-imports': utils_1.WARN,
        '@typescript-eslint/no-this-alias': utils_1.WARN,
        '@typescript-eslint/no-type-alias': (0, utils_1.OFF)('The absence of Opaque types in TypeScript is the only remaining feature I miss from FlowType.  Until such a thing is implemented some day (and we seem to get closer every major release) I will continue to use aliases for primitive types.'),
        '@typescript-eslint/no-unnecessary-boolean-literal-compare': utils_1.WARN,
        '@typescript-eslint/no-unnecessary-condition': utils_1.WARN,
        '@typescript-eslint/no-unnecessary-qualifier': utils_1.WARN,
        '@typescript-eslint/no-unnecessary-type-arguments': utils_1.WARN,
        '@typescript-eslint/no-unnecessary-type-assertion': utils_1.WARN,
        '@typescript-eslint/no-unnecessary-type-constraint': utils_1.WARN,
        '@typescript-eslint/no-unsafe-assignment': utils_1.WARN,
        '@typescript-eslint/no-unsafe-call': utils_1.WARN,
        '@typescript-eslint/no-unsafe-member-access': utils_1.WARN,
        '@typescript-eslint/no-unsafe-return': utils_1.WARN,
        '@typescript-eslint/no-unsafe-argument': utils_1.WARN,
        '@typescript-eslint/no-useless-empty-export': utils_1.WARN,
        '@typescript-eslint/non-nullable-type-assertion-style': (0, utils_1.OFF)('using non-null assertions cancels the benefits of the strict null-checking mode..'),
        '@typescript-eslint/no-var-requires': utils_1.WARN,
        '@typescript-eslint/parameter-properties': (0, utils_1.OFF)(),
        '@typescript-eslint/prefer-as-const': utils_1.WARN,
        '@typescript-eslint/prefer-enum-initializers': utils_1.WARN,
        '@typescript-eslint/prefer-for-of': (0, utils_1.SUCCESSOR)('unicorn/no-for-loop'),
        '@typescript-eslint/prefer-function-type': (0, utils_1.OFF)('Certain abstractions read clearer when documented by interfaces, even those with only one call signature.'),
        '@typescript-eslint/prefer-includes': utils_1.WARN,
        '@typescript-eslint/prefer-literal-enum-member': utils_1.WARN,
        '@typescript-eslint/prefer-namespace-keyword': (0, utils_1.OFF)(),
        '@typescript-eslint/prefer-nullish-coalescing': utils_1.WARN,
        '@typescript-eslint/prefer-optional-chain': utils_1.WARN,
        '@typescript-eslint/prefer-readonly': utils_1.WARN,
        '@typescript-eslint/prefer-readonly-parameter-types': (0, utils_1.OFF)('While using parameters should never be modified and making them readonly helps with this, some third party interfaces are not easily made readonly'),
        '@typescript-eslint/prefer-reduce-type-parameter': utils_1.WARN,
        '@typescript-eslint/prefer-regexp-exec': utils_1.WARN,
        '@typescript-eslint/prefer-return-this-type': utils_1.WARN,
        '@typescript-eslint/prefer-string-starts-ends-with': utils_1.WARN,
        '@typescript-eslint/prefer-ts-expect-error': utils_1.WARN,
        '@typescript-eslint/promise-function-async': utils_1.WARN,
        '@typescript-eslint/require-array-sort-compare': [utils_1.WARN, { ignoreStringArrays: true }],
        '@typescript-eslint/restrict-plus-operands': [utils_1.WARN, { checkCompoundAssignments: true }],
        '@typescript-eslint/restrict-template-expressions': (0, utils_1.BUGGY)('@typescript-eslint:v2.9.0', 'seems to have a lot of false positives with the null coalescing operator'),
        '@typescript-eslint/sort-type-union-intersection-members': utils_1.WARN,
        '@typescript-eslint/strict-boolean-expressions': utils_1.WARN,
        '@typescript-eslint/switch-exhaustiveness-check': utils_1.WARN,
        '@typescript-eslint/triple-slash-reference': utils_1.WARN,
        '@typescript-eslint/type-annotation-spacing': (0, utils_1.OFF)(utils_1.CODE_FORMATTING),
        '@typescript-eslint/typedef': (0, utils_1.OFF)('type inference is your friend... use it.'),
        '@typescript-eslint/unbound-method': [
            utils_1.WARN,
            {
                ignoreStatic: true,
            },
        ],
        '@typescript-eslint/unified-signatures': utils_1.WARN,
    },
    overrides: [
        {
            files: ['jest.config.ts'],
            rules: {
                'import/no-anonymous-default-export': (0, utils_1.OFF)(),
                '@typescript-eslint/naming-convention': (0, utils_1.OFF)('globals uses package names which use kebab case'),
            },
        },
    ],
};
//# sourceMappingURL=typescript.js.map