"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ES2021 = exports.LARGE_PERFORMANCE_COST = exports.USER_DISCRETION = exports.TYPESCRIPT = exports.MARKDOWN = exports.JAVASCRIPT = exports.CODE_FORMATTING = exports.NOT_RELEVANT = exports.NOT_VALUABLE = exports.PROJECT_BY_PROJECT = exports.UNKNOWN = exports.BUGGY = exports.DEPRECATED = exports.ERROR = exports.WARN = exports.TYPESCRIPT_EXTENDED = exports.SUCCESSOR = exports.OFF = void 0;
/**
 * Used to indicate a rule that has been turned off and optionally
 * explain why
 *
 * @param _reason the rationale for not using the rule.
 * @return the rule disabled
 */
const OFF = (_reason) => 'off';
exports.OFF = OFF;
/**
 * Some plugins extend rules of other plugins.
 * For example, the typescript plugin may extend a rule in the base eslint rule set.
 *
 * @param _ruleId the rule that takes precedence over this one
 * @return the rule disabled
 */
const SUCCESSOR = (_ruleId) => 'off';
exports.SUCCESSOR = SUCCESSOR;
/**
 * Used for `@typescript-eslint` extension rules for eslint rules of the same name.
 * see: https://github.com/typescript-eslint/typescript-eslint/tree/master/packages/eslint-plugin#extension-rules
 */
exports.TYPESCRIPT_EXTENDED = '@typescript-eslint/*';
exports.WARN = 'warn';
exports.ERROR = 'error';
exports.DEPRECATED = 'off';
/**
 * Used when a rule is only turned off because it was found not to work well.
 *
 * @param _asOfVersion the version of the parser or plugin when last investigated
 * @param _reason the reason why this rule was found to be buggy
 * @return the rule disabled
 */
const BUGGY = (_asOfVersion, _reason) => 'off';
exports.BUGGY = BUGGY;
/**
 * This is useful when adding many new rules at once.
 */
exports.UNKNOWN = 'off';
/**
 * Used to signal that while a rule may have utility, it should really be configured differently
 * depending on the project.
 */
exports.PROJECT_BY_PROJECT = 'This is a project-by-project rule that should be configured differently depending on the project.';
/** Used to signify that the rule in question is borderline-useless. */
exports.NOT_VALUABLE = "I don't see enough value to justify including this rule.";
/** Used to signify that the rule in question is not useful for this particular platform */
exports.NOT_RELEVANT = "I don't see enough value to justify including this rule.";
/**
 * Used to signal that while a rule may be useful for formatting, formatting itself ise beyond the
 * scope of this config
 */
exports.CODE_FORMATTING = 'Code formatting rules are unnecessary when using prettier';
/** This rule is turned off in an override for *.js files only because it requires typescript */
exports.JAVASCRIPT = 'off';
exports.MARKDOWN = 'off';
exports.TYPESCRIPT = 'off';
exports.USER_DISCRETION = 'off';
/**
 * This rule is disabled due to the performance cost of running the rule being greater than the
 * benefit of the rule itself.
 */
exports.LARGE_PERFORMANCE_COST = 'off';
/**
 * Our stack currently does not support es2021
 */
exports.ES2021 = 'off';
//# sourceMappingURL=utils.js.map